package com.ruoyi.invest.service;

import com.ruoyi.invest.domain.CreditReportQueryRecord;
import com.ruoyi.invest.domain.dto.CreditReportQueryRecordDto;
import com.ruoyi.invest.domain.vo.CreditReportAnalysisVO;
import com.ruoyi.invest.domain.vo.CreditReportQueryRecordVo;

import java.util.List;

/**
 * 征信报告查询记录Service接口
 *
 * @author tianyongbao
 * @date 2024-03-20
 */
public interface ICreditReportQueryRecordService
{
    /**
     * 查询征信报告查询记录
     *
     * @param id 征信报告查询记录主键
     * @return 征信报告查询记录
     */
    public CreditReportQueryRecordVo selectCreditReportQueryRecordById(Long id);

    /**
     * 查询征信报告查询记录列表
     *
     * @param creditReportQueryRecordDto 征信报告查询记录
     * @return 征信报告查询记录集合
     */
    public List<CreditReportQueryRecordVo> selectCreditReportQueryRecordList(CreditReportQueryRecordDto creditReportQueryRecordDto);

    /**
     * 新增征信报告查询记录
     *
     * @param creditReportQueryRecord 征信报告查询记录
     * @return 结果
     */
    public int insertCreditReportQueryRecord(CreditReportQueryRecord creditReportQueryRecord);

    /**
     * 修改征信报告查询记录
     *
     * @param creditReportQueryRecord 征信报告查询记录
     * @return 结果
     */
    public int updateCreditReportQueryRecord(CreditReportQueryRecord creditReportQueryRecord);

    /**
     * 批量删除征信报告查询记录
     *
     * @param ids 需要删除的征信报告查询记录主键集合
     * @return 结果
     */
    public int deleteCreditReportQueryRecordByIds(Long[] ids);

    /**
     * 删除征信报告查询记录信息
     *
     * @param id 征信报告查询记录主键
     * @return 结果
     */
    public int deleteCreditReportQueryRecordById(Long id);

    /**
     * 查询征信报告查询记录
     *
     * @return 征信报告查询记录
     */
    public CreditReportAnalysisVO selectCreditReportAnalysis(CreditReportQueryRecordDto creditReportQueryRecordDto);

    /**
     * 查询征信报告查询记录列表
     *
     * @param creditReportQueryRecordDto 征信报告查询记录
     * @return 征信报告查询记录集合
     */
    public List<CreditReportQueryRecordVo> selectQueryInstitutionList(CreditReportQueryRecordDto creditReportQueryRecordDto);

}
